diff --git a/GAME/include/personnage.h b/GAME/include/personnage.h
index 62428cb376651fc885a30e8f0494002d3c1723dc..6715b878c2a00fd6b376e6a96f852c7f8440fb60 100644
--- a/GAME/include/personnage.h
+++ b/GAME/include/personnage.h
@@ -17,7 +17,7 @@
 #define GAME_INSA_PROJECT_PERSONNAGE_H
 
 /*!
- * \struct personnage
+ * \struct Personnage
  * \brief Character structure
  */
 
diff --git a/GAME/include/prof.h b/GAME/include/prof.h
index 0ddfbaca3a23d014b1682bd0747265627199de4c..cb28421d39df3a6fde6b154d2664a75bab8b0ea3 100644
--- a/GAME/include/prof.h
+++ b/GAME/include/prof.h
@@ -6,12 +6,12 @@
 
 /*!
  * \file prof.h
  * \brief Character Header File
  * \authors  corto
  * \version 1
  * \date 25/02/2021
  *
  * Character structure definiton.
  *
  */
 
@@ -19,8 +19,8 @@
 #define GAME_INSA_PROJECT_PROF_H
 
 /*!
  * \struct prof
  * \brief Character structure
  */
 
 typedef struct {
@@ -28,9 +28,9 @@ typedef struct {
     int y_prof; /**< Position : ordinate */
     int long_porf; /**< Size : length */
     int larg_prof; /**< Size : width */
-    int speed_prof; /**< Charater speed */
-    char * image_prof; /**< Source image of the character. */
-} prof;
+    int speed_prof; /**< Teacher speed */
+    char * image_prof; /**< Source image of the teacher. */
+} Prof;
 
 #endif /*GAME_INSA_PROJECT_Prof_H*/
@@ -6,12 +6,12 @@
 /*!
  * \file prof.h
- * \brief Character Header File
- * \authors  corto
+ * \brief Teacher Header File
+ * \authors  Corto
  * \version 1
  * \date 25/02/2021
@@ -6,12 +6,12 @@
  * \date 25/02/2021
  *
- * Character structure definiton.
+ * Teacher structure and functions definiton.
  *
  */
@@ -19,8 +19,8 @@
 
 /*!
- * \struct prof
- * \brief Character structure
+ * \struct Prof
+ * \brief Teacher structure
  */
 